<?php
//* Start the engine
include_once( get_template_directory() . '/lib/init.php' );

//* Child theme (do not remove)
define( 'CHILD_THEME_NAME', 'Envy' );
define( 'CHILD_THEME_URL', 'http://envy.krolyn.com' );
define( 'CHILD_THEME_VERSION', '1.4.0' );

//* Set localization (do not remove)
load_child_theme_textdomain( 'envy', apply_filters( 'child_theme_textdomain', get_stylesheet_directory() . '/lib/languages', 'envy' ) );

//* Enqueue scripts
add_action( 'wp_enqueue_scripts', 'envy_scripts' );
function envy_scripts() {
	wp_enqueue_style( 'google-fonts', '//fonts.googleapis.com/css?family=Raleway:200,300,400,500,600', array(), CHILD_THEME_VERSION );
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_script( 'envy-responsive-menu', get_stylesheet_directory_uri() . '/lib/js/responsive-menu.js', array( 'jquery' ), '1.3', true );
	$output = array(
		'mainMenu' => __( 'Menu', 'envy' ),
		'subMenu'  => __( 'Menu', 'envy' ),
	);
	wp_localize_script( 'envy-responsive-menu', 'envyL10n', $output );
	wp_enqueue_script( 'main', get_stylesheet_directory_uri() . '/lib/js/main.js', array( 'jquery' ), '1.3', true );
}

//* Add HTML5 markup structure
add_theme_support( 'html5' );

//* Add accessibility features
add_theme_support( 'genesis-accessibility', 
  array( 'headings', 'drop-down-menu', 'search-form', 'skip-links', 'rems' ) 
);

//* Add viewport meta tag for mobile browsers
add_theme_support( 'genesis-responsive-viewport' );

//* Add theme support for 3-column footer widgets
add_theme_support( 'genesis-footer-widgets', 3 );

//* Add theme support for custom header
add_theme_support( 'custom-header', array(
	'width'           => 260,
	'height'          => 100,
	'header-selector' => '.site-title a',
	'header-text'     => false
) );

//* Add support for custom background
add_theme_support( 'custom-background' );

//* Add theme support for additional color style options
add_theme_support( 'genesis-style-selector', array(
	'envy-green'      => __( 'Green With Envy', 'envy' ),
	'envy-orange'     => __( 'Orange With Envy', 'envy' ),
	'envy-purple'     => __( 'Purple With Envy', 'envy' ),
	'envy-pink'       => __( 'Pink With Envy', 'envy' ),
	'envy-blue'       => __( 'Blue With Envy', 'envy' ),
	'envy-dark-blue'  => __( 'Dark Blue (WCAG2AA)', 'envy' ),
) );

//* Enable shortcodes in widgets
add_filter('widget_text', 'do_shortcode');

//* Remove the site description
remove_action( 'genesis_site_description', 'genesis_seo_site_description' );

//* Unregister site layouts
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );
genesis_unregister_layout( 'sidebar-content-sidebar' );

//* Relocate Secondary Sidebar to before loop and append (Top)
unregister_sidebar( 'sidebar-alt' );
genesis_register_sidebar( array( 'id' => 'sidebar-alt', 'name' => __( 'Secondary Sidebar (Top)', 'envy' ) ) );
remove_action( 'genesis_after_content', 'genesis_get_sidebar_alt' );
add_action( 'genesis_before_loop', 'genesis_get_sidebar_alt' );

//* Register new layouts with Secondary Sidebar (Top)
genesis_register_layout( 'topbar-content-sidebar', array(
	'label'	=> __('Topbar/Content/Sidebar', 'envy'),
	'img'	=> get_stylesheet_directory_uri() . '/lib/icons/tcs.gif'
) );
genesis_register_layout( 'sidebar-topbar-content', array(
	'label'	=> __('Sidebar/Topbar/Content', 'envy'),
	'img'	=> get_stylesheet_directory_uri() . '/lib/icons/stc.gif'
) );

//* Register widget areas
genesis_register_sidebar( array(
	'id'			=> 'home-slider',
	'name'			=> __( 'Home Slider', 'envy' ),
	'description'	=> __( 'This is the Slider (full-width) section of the homepage.', 'envy' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-featured-products',
	'name'			=> __( 'Home Featured Products', 'envy' ),
	'description'	=> __( 'This is the Featured Products (full-width) section of the homepage.', 'envy' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'call-to-action',
	'name'			=> __( 'Home Call-to-Action', 'envy' ),
	'description'	=> __( 'This is the Call-to-Action (full-width) section of the homepage.', 'envy' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-featured-content',
	'name'			=> __( 'Home Featured Content', 'envy' ),
	'description'	=> __( 'This is the Featured Content (two-thirds-width) section of the homepage.', 'envy' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'sponsor-logos',
	'name'			=> __( 'Sponsor Logos', 'envy' ),
	'description'	=> __( 'This is the Sponsor Logos (full-width) section of the homepage.', 'envy' ),
) );

//* Add Sponsor Logos widget area above footer
add_action( 'genesis_before_footer', 'envy_sponsor_logos_widget' );
function envy_sponsor_logos_widget() {
	genesis_widget_area( 'sponsor-logos', array(
		'before' => '<div class="sponsor-logos widget-area">',
		'after' => '</div>',
	) );
}
remove_action( 'genesis_before_footer', 'genesis_footer_widget_areas' );
add_action( 'genesis_before_footer', 'genesis_footer_widget_areas' );

//* Add new image sizes
add_image_size( 'slider', 1200, 450, TRUE );
add_image_size( 'featured', 720, 210, TRUE );

//* Position Primary Menu within header
remove_action( 'genesis_after_header', 'genesis_do_nav' );
add_action( 'genesis_header', 'genesis_do_nav', 12 );

//* Position Secondary Menu before header
remove_action( 'genesis_after_header', 'genesis_do_subnav' );
add_action( 'genesis_before_header', 'genesis_do_subnav' );

//* Assign ID to Secondary Menu (for skip-links)
add_filter( 'genesis_attr_nav-secondary', 'envy_add_nav_secondary_id' );
function envy_add_nav_secondary_id( $attributes ) {
	$attributes[ 'id' ] = 'genesis-secondary-nav';
	return $attributes;
}

//* Remove header widget area if Primary Menu active
add_action ( 'init', 'envy_remove_header_right_sidebar' );
function envy_remove_header_right_sidebar() {
	if( has_nav_menu( 'primary' ) ) {
		unregister_sidebar( 'header-right' );
		add_filter( 'body_class', 'remove_body_class' );
		function remove_body_class( $classes ) {
			foreach( $classes as $key => $value ) {
 				if ( $value == 'header-full-width' ) unset( $classes[ $key ] );
 			}
			return $classes;
		}
	}
}

//* Add skip-links to Secondary Menu
add_filter( 'genesis_skip_links_output', 'envy_add_nav_secondary_skip_link' );
function envy_add_nav_secondary_skip_link( $links ) {
	$new_links = $links;
	array_splice( $new_links, 1 );
	if ( has_nav_menu( 'secondary' ) ) {
		$new_links[ 'genesis-secondary-nav' ] = __( 'Skip to secondary navigation', 'envy' );
	}
	return array_merge( $new_links, $links );
}

//* Set Genesis Responsive Slider defaults
add_filter( 'genesis_responsive_slider_settings_defaults', 'envy_responsive_slider_defaults' );
function envy_responsive_slider_defaults( $defaults ) { 
	$args = array( 
		'posts_num'                       => '3',
		'slideshow_pager'		  	      => '',
		'slideshow_height'                => '450',
		'slideshow_width'                 => '1200',
		'slideshow_excerpt_content'       => 'full',
		'slideshow_excerpt_content_limit' => '',
		'slideshow_more_text'             => __( 'More Details', 'envy' ),
		'slideshow_excerpt_width'         => '45',
		'slideshow_title_show'            => 1,
		'location_horizontal'             => 'right',
		'location_vertical'               => 'top'
	); 
	$args = wp_parse_args( $args, $defaults );	
	return $args;
}
 
//* Customize search form placeholder and button text
add_filter( 'genesis_search_text', 'envy_search_text' );
function envy_search_text( $text ) {
	return esc_attr( __('Website search', 'envy') );
}
add_filter( 'genesis_search_button_text', 'envy_search_button' );
function envy_search_button( $text ) {
	return esc_attr( '&#xf179;', 'envy' );
}

//* Relocate page titles to before the loop
add_action( 'get_header', 'envy_relocate_page_titles' );
function envy_relocate_page_titles() {
	if( ! is_page_template( 'page_blog.php' ) && is_singular( 'page' ) ) {
		remove_action( 'genesis_entry_header', 'genesis_do_post_title' );
		add_action ( 'genesis_before_loop', 'genesis_do_post_title' );
	}
}

//* Change archive pagination previous and next texts
add_filter( 'genesis_prev_link_text', 'envy_prev_link_text' );
function envy_prev_link_text() {
	$prevlink = '&#8592; <span class="screen-reader-text">' . __( 'Previous', 'envy' ) . '</span>';
	return $prevlink;
}
add_filter( 'genesis_next_link_text', 'envy_next_link_text' );
function envy_next_link_text() {
	$nextlink = '<span class="screen-reader-text">' . __( 'Next', 'envy' ) . '</span> &#8594;';
	return $nextlink;
}


/**
 * WooCommerce functions
 */
 
//* Add theme support for WooCommerce
add_theme_support( 'genesis-connect-woocommerce' );
add_theme_support( 'wc-product-gallery-zoom' );
add_theme_support( 'wc-product-gallery-lightbox' );
add_theme_support( 'wc-product-gallery-slider' );
 
//* Add custom style sheet for WooCommerce
add_action('wp_enqueue_scripts', 'envy_woocommerce_styles');
function envy_woocommerce_styles() {
	wp_enqueue_style( 'woocommerce-styling', get_stylesheet_directory_uri() . '/woocommerce/woocommerce.css' );
}

//* Redefine WooCommerce default image sizes
add_action( 'after_switch_theme', 'envy_woocommerce_image_dimensions', 1 );
function envy_woocommerce_image_dimensions() {
	global $pagenow;
	if ( ! isset( $_GET[ 'activated' ] ) || $pagenow != 'themes.php' ) {
		return;
	}
	$catalog = array(
		'width' 	=> '320',
		'height'	=> '320',
		'crop'		=> 1
	); 
	$single = array(
		'width' 	=> '440',
		'height'	=> '440',
		'crop'		=> 1
	);
	$thumbnail = array(
		'width' 	=> '90',
		'height'	=> '90',
		'crop'		=> 0
	);
	update_option( 'shop_catalog_image_size', $catalog );
	update_option( 'shop_single_image_size', $single );
	update_option( 'shop_thumbnail_image_size', $thumbnail );
}

//* Customize text in WooCommerce sale-flash
add_filter('woocommerce_sale_flash', 'envy_sale_flash', 10, 3);
function envy_sale_flash($text, $post, $_product) {
	return '<span class="onsale">' . __( 'Special', 'envy' ) . '</span>';  
}

//* Customize WooCommerce product search form
add_filter( 'get_product_search_form' , 'envy_product_searchform' );
function envy_product_searchform( $form ) {
	$form = '<form role="search" method="get" id="searchform" action="' . esc_url( home_url( '/'  ) ) . '">
		<div>
			<input type="text" value="' . get_search_query() . '" name="s" id="s" placeholder="' . __( 'Product search', 'envy' ) . '" />
			<input type="submit" id="searchsubmit" value="'. esc_attr__( '&#xf179;', 'envy' ) .'" />
			<input type="hidden" name="post_type" value="product" />
		</div>
	</form>';
	return $form;	
}

//* Set number of columns for shop page
add_filter( 'loop_shop_columns', 'loop_columns' );
if( ! function_exists( 'loop_columns' ) ) {
	function loop_columns() {
		return 3; // 3 columns (default for shop, related, upsell)
	}
}

//* Add columns- body class as per shop
add_filter( 'body_class', 'envy_loop_columns_body_class' );
function envy_loop_columns_body_class( $classes ) {
	if( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
		$classes[] = 'columns-' . loop_columns();
	}
	return $classes;
}

//* Set number to show on shop page
add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 12;' ), 20 ); // Show 12 products
	
//* Set grid for related products
add_filter( 'woocommerce_output_related_products_args', 'envy_related_products_args' );
function envy_related_products_args( $args ) {
	$args[ 'posts_per_page' ]     = 3; // Show 3 products
	$args[ 'columns' ]            = loop_columns(); // Columns (default)
	return $args;
}

//* Replace default placeholder image with custom image
add_action( 'init', 'envy_custom_thumbnail' );
function envy_custom_thumbnail() {
	add_filter( 'woocommerce_placeholder_img_src', 'envy_custom_placeholder_img_src' );   
	function envy_custom_placeholder_img_src( $src ) {
		$src = get_stylesheet_directory_uri() . '/images/placeholder.gif';	 
		return $src;
	}
}

//* Replace WooCommerce pagination with Genesis pagination
remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
add_action( 'woocommerce_after_shop_loop', 'genesis_posts_nav', 10 );

//* Remove duplicate page-title from WooCommerce archive pages
add_filter( 'woocommerce_show_page_title', 'envy_hide_page_titles' );
function envy_hide_page_titles() {
	if ( is_shop() )
	return true;
}
